"use strict";
const multer = require('multer');
const MIME_TYPE_MAP = {
    'image/png': 'png',
    'image/jpeg': 'jpeg',
    'image/jpg': 'jpg',
    'text/csv': 'csv',
    'application/pdf': 'pdf',
    'text/plain': 'txt'
};
const storage = multer.diskStorage({
    destination: (req, file, cb) => {
        const isValid = MIME_TYPE_MAP[file.mimetype];
        let error = "";
        if (!isValid) {
            error = new Error("Invalid file type");
        }
        cb(error, "uploads");
    },
    filename: (req, file, cb) => {
        const name = file.originalname.toLowerCase().split(' ').join('_');
        const ext = MIME_TYPE_MAP[file.mimetype];
        cb(null, Date.now() + '-' + name);
    }
});
module.exports = multer({ storage: storage }).single('profile_pic');
